Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1668)

Unified Diff: chrome/browser/views/bookmark_editor_view.h

Issue 271115: Makes canceling 'bookmark all tabs' delete the folder. Or rather,... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/views/bookmark_editor_view.h
===================================================================
--- chrome/browser/views/bookmark_editor_view.h (revision 29276)
+++ chrome/browser/views/bookmark_editor_view.h (working copy)
@@ -69,7 +69,7 @@
BookmarkEditorView(Profile* profile,
const BookmarkNode* parent,
- const BookmarkNode* node,
+ const EditDetails& details,
BookmarkEditor::Configuration configuration,
BookmarkEditor::Handler* handler);
@@ -167,7 +167,7 @@
EditorNode* CreateRootNode();
// Adds and creates a child node in b_node for all children of bb_node that
- // are groups, except for |node_| if editing a folder.
+ // are groups.
void CreateNodes(const BookmarkNode* bb_node, EditorNode* b_node);
// Returns the node with the specified id, or NULL if one can't be found.
@@ -215,9 +215,6 @@
// internally by NewGroup and broken into a separate method for testing.
EditorNode* AddNewGroup(EditorNode* parent);
- // Returns true if editing a folder.
- bool IsEditingFolder() const;
-
// Profile the entry is from.
Profile* profile_;
@@ -236,11 +233,11 @@
// Used for editing the title.
views::Textfield title_tf_;
// Initial parent to select. Is only used if node_ is NULL.
const BookmarkNode* parent_;
- // Node being edited. Is NULL if creating a new node.
- const BookmarkNode* node_;
+ const EditDetails details_;
// The context menu.
scoped_ptr<views::SimpleMenuModel> context_menu_contents_;
@@ -236,11 +233,11 @@
// Used for editing the title.
views::Textfield title_tf_;
- // Initial parent to select. Is only used if node_ is NULL.
+ // Initial parent to select. Is only used if |details_.existing_node| is
+ // NULL.
const BookmarkNode* parent_;

Powered by Google App Engine
This is Rietveld 408576698